@@ -12,6 +12,7 @@ class VM:
                  imagem, regiao,
                  qtde_cpu, qtde_ram_mb, redes,
                  id_vmm=None,
+                 virt_aninhada=False,
                  status=VMStatusEnum.EM_EXECUCAO,
                  no_regiao=None):
         self.nome = nome
@@ -24,6 +25,7 @@ class VM:
         self.id_vmm = id_vmm
         self.status = status
         self.no_regiao = no_regiao
+        self.virt_aninhada = virt_aninhada
 
         self.dados_ansible = {}
         self.discos_adicionais = {}
@@ -61,15 +63,15 @@ class VM:
                         vm_remota.id_vmm))
 
         # verificando discos atuais
-        for nome_disco in self.discos_adicionais:
+        for nome_disco, data_disco in self.discos_adicionais.items():
             # discos a criar
             if not vm_remota or not nome_disco in vm_remota.discos_adicionais:
                 plano_execucao.acoes.append(
-                    self.discos_adicionais[nome_disco].get_acao_criar_disco(self.nome))
+                    data_disco.get_acao_criar_disco(self.nome))
             else:
                 # discos a alterar
                 plano_execucao.acoes.extend(
-                    self.discos_adicionais[nome_disco].get_acoes_diferenca_disco(
+                    data_disco.get_acoes_diferenca_disco(
                         vm_remota.discos_adicionais[nome_disco], vm_remota.id_vmm, self.nome))
 
     def add_acoes_diferenca_regiao(self, vm_remota,
@@ -81,6 +83,13 @@ class VM:
             plano_execucao.acoes.append(self.get_acao_mover_vm_regiao(
                 inv_remoto.get_id_no_regiao(self.regiao)))
 
+    def add_acoes_virt_aninhada(self, vm_remota,
+                                plano_execucao):
+        if ((not vm_remota and self.virt_aninhada)
+                or (vm_remota and vm_remota.virt_aninhada != self.virt_aninhada)):
+            plano_execucao.acoes.append(
+                self.get_acao_atualizar_virt_aninhada())
+
     def add_acoes_diferenca_vm(self, vm_remota, plano_execucao):
         # alteração da imagem é irreversível
         if self.imagem != vm_remota.imagem:
@@ -129,6 +138,11 @@ class VM:
                     id_no_regiao=id_no_regiao,
                     regiao=self.regiao)
 
+    def get_acao_atualizar_virt_aninhada(self):
+        return Acao('atualizar_virt_aninhada',
+                    nome_vm=self.nome,
+                    virt_aninhada=self.virt_aninhada)
+
     def get_acao_atualizar_vm(self, id_vm_remota):
         return Acao('atualizar_vm',
                     id_vm=id_vm_remota,
@@ -176,12 +190,12 @@ class VM:
             'id_vmm': self.id_vmm,
             'status': self.status.value,
             'no_regiao': self.no_regiao,
-            'ansible': [self.dados_ansible[dados_ansible].to_dict()
-                        for dados_ansible in self.dados_ansible]
+            'ansible': [data_ansible.to_dict()
+                        for data_ansible in self.dados_ansible.values()]
         }
 
         if self.to_json_dados_completos:
-            dict_objeto['discos_adicionais'] = [self.discos_adicionais[disco_adicional].to_dict()
-                                                for disco_adicional in self.discos_adicionais]
+            dict_objeto['discos_adicionais'] = [data_disco.to_dict()
+                                                for data_disco in self.discos_adicionais.values()]
 
         return dict_objeto
